@@ -19,8 +19,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __GTK_SOURCE_COMPLETION_WORDS_LIBRARY_H__
-#define __GTK_SOURCE_COMPLETION_WORDS_LIBRARY_H__
+#ifndef GTK_SOURCE_COMPLETION_WORDS_LIBRARY_H
+#define GTK_SOURCE_COMPLETION_WORDS_LIBRARY_H
 
 #include <glib-object.h>
 #include "gtksourcecompletionwordsproposal.h"
@@ -97,4 +97,4 @@ void		 gtk_source_completion_words_library_unlock 		(GtkSourceCompletionWordsLib
 
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_COMPLETION_WORDS_LIBRARY_H__ */
+#endif /* GTK_SOURCE_COMPLETION_WORDS_LIBRARY_H */
